Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(744)

Unified Diff: chrome/browser/profiles/profile_shortcut_manager_win.cc

Issue 16950028: Move file_util::Delete to the base namespace (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Created 7 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/profiles/profile_shortcut_manager_win.cc
diff --git a/chrome/browser/profiles/profile_shortcut_manager_win.cc b/chrome/browser/profiles/profile_shortcut_manager_win.cc
index e3e0c3caa5bc206d7e996b6a60bff5dfa42d7833..754e5d6fe9a5666b99c49fcb37a5b147b917a6ca 100644
--- a/chrome/browser/profiles/profile_shortcut_manager_win.cc
+++ b/chrome/browser/profiles/profile_shortcut_manager_win.cc
@@ -292,7 +292,7 @@ void RenameChromeDesktopShortcutForProfile(
const base::FilePath possible_new_system_shortcut =
system_shortcuts_directory.Append(new_shortcut_filename);
if (file_util::PathExists(possible_new_system_shortcut))
- file_util::Delete(old_shortcut_path, false);
+ base::Delete(old_shortcut_path, false);
else if (!RenameDesktopShortcut(old_shortcut_path, new_shortcut_path))
DLOG(ERROR) << "Could not rename Windows profile desktop shortcut.";
} else {
@@ -437,9 +437,9 @@ void DeleteDesktopShortcutsAndIconFile(const base::FilePath& profile_path,
BrowserDistribution* distribution = BrowserDistribution::GetDistribution();
for (size_t i = 0; i < shortcuts.size(); ++i) {
// Use file_util::Delete() instead of ShellUtil::RemoveShortcut(), as the
// latter causes non-profile taskbar shortcuts to be unpinned.
- file_util::Delete(shortcuts[i], false);
+ base::Delete(shortcuts[i], false);
// Notify the shell that the shortcut was deleted to ensure desktop refresh.
SHChangeNotify(SHCNE_DELETE, SHCNF_PATH, shortcuts[i].value().c_str(),
NULL);
@@ -447,7 +447,7 @@ void DeleteDesktopShortcutsAndIconFile(const base::FilePath& profile_path,
const base::FilePath icon_path =
profile_path.AppendASCII(profiles::internal::kProfileIconFileName);
- file_util::Delete(icon_path, false);
+ base::Delete(icon_path, false);
// If |ensure_shortcuts_remain| is true and deleting this profile caused the
// last shortcuts to be removed, re-create a regular non-profile shortcut.
@@ -437,9 +437,9 @@ void DeleteDesktopShortcutsAndIconFile(const base::FilePath& profile_path,
BrowserDistribution* distribution = BrowserDistribution::GetDistribution();
for (size_t i = 0; i < shortcuts.size(); ++i) {
- // Use file_util::Delete() instead of ShellUtil::RemoveShortcut(), as the
+ // Use base::Delete() instead of ShellUtil::RemoveShortcut(), as the
// latter causes non-profile taskbar shortcuts to be unpinned.

Powered by Google App Engine
This is Rietveld 408576698